<?php
$lang['friendlyname'] = 'TinyMCE';
$lang['admindescription'] = 'Mit diesem Modul k&ouml;nnen haupts&auml;chlich Inhalte, aber auch alle anderen Arten von Daten &uuml;ber den WYSIWYG-Editor des TinyMCE-Projekts bearbeitet werden.';
$lang['uninstalled'] = 'Das Modul wurde deinstalliert.';
$lang['installed'] = 'Das Modul wurde in der Version %s installiert.';
$lang['stripbackgroundtags'] = 'CSS-Stile f&uuml;r den Hintergrund entfernen';
$lang['stiptags_help'] = 'Diese Option versucht, die im Stylesheet enthaltenen Vorgaben f&uuml;r den Hintergrund zu entfernen.';
$lang['source_formatting_text'] = 'Formatierung des Quellcodes auf die HTML-Ausgabe anwenden';
$lang['dropdownblockformats_text'] = 'Blockformate im Listenfeld-Men&uuml;';
$lang['allowtables'] = 'Tabellen-Operationen erlauben';
$lang['newlinestyle_text'] = 'Neue Zeilen erstellen mit';
$lang['pstyle'] = 'Absatz (via p)';
$lang['brstyle'] = 'Zeilenumbruch (via br)';
$lang['usecompressiontext'] = 'GZIP-Kompression verwenden';
$lang['usecompressionhelp'] = 'Dies kann das Laden von TinyMCE beschleunigen, aber unter bestimmten Umst&auml;nden auch das Laden verhindern. Verwenden Sie daher diese Funktion mit Bedacht.';
$lang['forcedrootblocktext'] = 'Absatz erzwingen';
$lang['forcedrootblockhelp'] = 'Erzwingt, dass die Inhalte in einem Absatz ausgegeben werden (via p-Tag)';
$lang['filepickerstyle'] = 'Stil der Dateiauswahl';
$lang['filepickersize'] = 'Gr&ouml;&szlig;e des Dateiauswahlfeldes';
$lang['allowuploadtext'] = 'Das Hochladen und die Erstellung von Verzeichnissen im Filepicker erlauben';
$lang['allowscalingtext'] = 'Eine sofortige Gr&ouml;&szlig;en&auml;nderungen der hochgeladenen Bilddateien erlauben';
$lang['scalingdimensionstext'] = 'Voreingestellte Abmessungen';
$lang['resizeto'] = 'Gr&ouml;&szlig;e &auml;ndern auf:';
$lang['makethumbnail'] = 'Automatisch Vorschaubilder erstellen, wenn Bilder hochgeladen werden';
$lang['useadvancedprofile'] = 'Erweitertes TinyMCE-Profil verwenden';
$lang['saveprofile'] = 'Profil speichern';
$lang['profilesaved'] = 'Das Profil wurde gespeichert';
$lang['profiles_tab'] = 'Profile';
$lang['advanced_backend_toolbars'] = 'Erweiterte Profileinstellungen f&uuml;r die Administration ';
$lang['savestyles'] = 'Styles speichern';
$lang['allowadvancedprofile'] = 'Die Verwendung von erweiterten Profilen im TinyMCE erlauben';
$lang['showfilemanagement'] = 'Optionen zur Dateiverwaltung anzeigen';
$lang['showfilemanagementhelp'] = 'Optionen zur Dateiverwaltung wie Hochladen, Verzeichnis erstellen und Dateien l&ouml;schen anzeigen (falls dem Benutzer das Ausf&uuml;hren dieser Aktionen erlaubt ist)';
$lang['restrictdirs'] = 'Benutzer-Zugriff auf Verzeichnisse beschr&auml;nken';
$lang['restrictdirshelp'] = 'Hiermit k&ouml;nnen die M&ouml;glichkeiten eines Benutzers zur Verwaltung von Dateien auf ein Unterverzeichnis von &#039;/uploads&#039; beschr&auml;nkt werden, dessen Name identisch mit dem Benutzernamen ist. Wenn dieses Unterverzeichnis nicht existiert, wird es erstellt. Bitte beachten Sie, dass dies aktuell nur mit den Standard-Verzeichnisnamen uploads/images funktioniert. Dies soll sich aber in Zukunft &auml;ndern.';
$lang['deleteconfirmation'] = 'Wollen Sie diese Datei wirklich l&ouml;schen?';
$lang['deletefilesuccess'] = 'wurde gel&ouml;scht';
$lang['deletefilefailed'] = 'konnte nicht gel&ouml;scht werden';
$lang['deletesubdirfailed'] = 'konnte nicht gel&ouml;scht werden';
$lang['deletesubdirsuccess'] = 'wurde gel&ouml;scht';
$lang['deletedirconfirmation'] = 'Wollen Sie wirklich das leere Unterverzeichnis l&ouml;schen?';
$lang['deletedir'] = 'Leeres Unterverzeichnis l&ouml;schen';
$lang['deletefile'] = 'Datei l&ouml;schen';
$lang['cannotreadconfig'] = 'Konnte die Datei tinyconfig.php nicht auslesen, so dass TinyMCE m&ouml;glicherweise nicht funktioniert. Pr&uuml;fen Sie die Berechtigungen der Datei und des &uuml;bergeordneten Verzeichnisses . Diese sollten lesbar f&uuml;r alle, aber nur f&uuml;r Eigent&uuml;mer beschreibbar sein.';
$lang['filenameonly'] = 'Dateinamen anzeigen';
$lang['thumbnailsonly'] = 'Vorschaubilder anzeigen';
$lang['showthumbnailfilestext'] = 'Die Dateien der Vorschaubilder in der Liste anzeigen';
$lang['filenameandthumbnails'] = 'Dateinamen und Vorschaubilder anzeigen';
$lang['skinstext'] = 'Aussehen';
$lang['skinvariationtext'] = 'Variationen des Aussehens';
$lang['advancedwarning'] = '<strong>ACHTUNG!<br/>Die Ver&auml;nderung dieser Einstellungen kann zur Folge haben, dass TinyMCE nicht mehr funktioniert oder falschen Code generiert. Sie sollten hier nur Ver&auml;nderungen vornehmen, wenn Sie wissen, was Sie tun! Sie sollten auf jeden Fall vor Ihren Tests die TinyMCE-Webseite zu diesem Thema konsultieren.</strong>';
$lang['entityencoding_text'] = 'Kodierung der Entit&auml;ten (Umlaute, Sonderzeichen)';
$lang['rawencoding'] = 'RAW-Kodierung (ohne Ver&auml;nderungen)';
$lang['namedencoding'] = 'HTML-Kodierung (z. Bsp. &nbsp;)';
$lang['numericencoding'] = 'Numerische Kodierung (z. Bsp. &amp;#160;)';
$lang['show_path_text'] = 'Den Pfad des Elements in einer Zeile unterhalb des Editors anzeigen';
$lang['toolbar_tab'] = 'Werkzeugleiste';
$lang['toolbar_help'] = 'Diese Optionen kann eine durch Kommata getrennte Liste aller Buttons enthalten, die in die Werkzeugleiste angezeigt werden sollen.';
$lang['toolbar_text'] = 'Werkzeugleiste';
$lang['toolbarhelptext'] = 'Klicken Sie hier, um die Anleitung f&uuml;r die Werkzeugleiste im TinyMCE-Wiki anzuzeigen.';
$lang['editor_width_text'] = 'Breite des Editor-Feldes';
$lang['editor_height_text'] = 'H&ouml;he des Editor-Feldes';
$lang['auto'] = 'Automatisch';
$lang['or'] = 'oder';
$lang['testarea_tab'] = 'Testbereich';
$lang['showtestingoutput'] = 'Testausgabe zeigen';
$lang['testareaeditor'] = 'Editor f&uuml;r den Testbereich';
$lang['testareaoutput'] = 'Ausgabe des Testbereichs';
$lang['testareaoutputsource'] = 'Quellcode des Testbereichs';
$lang['allowresizing'] = 'Erlaubt die Gr&ouml;&szlig;en&auml;nderung von Bildern innerhalb des Editorfeldes';
$lang['resizenone'] = 'Keine Gr&ouml;&szlig;en&auml;nderung erlauben';
$lang['resizeboth'] = 'Gr&ouml;&szlig;en&auml;nderung in beide Richtungen erlauben';
$lang['resizeheight'] = 'Nur Gr&ouml;&szlig;en&auml;nderung der Bildh&ouml;he erlauben';
$lang['datetimeformat_text'] = 'Datums-/Zeit-Format';
$lang['timetext'] = 'Zeit';
$lang['datetext'] = 'Datum';
$lang['datetimeformat_help'] = 'Klicken Sie hier f&uuml;r Informationen, wie Sie die Ausgabe von Datum und Zeit formatieren k&ouml;nnen';
$lang['extraconfigtext'] = 'Weitere Optionen';
$lang['extraconfighelp2'] = 'Eine Vorgabe pro Zeile, Kommatas werden vor dem nach diesem Inhalt hinzugef&uuml;gt. F&uuml;r weitere Informationen schauen Sie ins Wiki auf der TinyMCE-Webseite.';
$lang['customdropdowntext'] = 'Benutzerdefiniertes Listenfeld';
$lang['customdropdownhelp'] = 'Hiermit k&ouml;nnen zuvor definierte Code- oder Text-Schnipsel &uuml;ber ein Listenfeld-Men&uuml; eingef&uuml;gt werden. Eine naheliegende Anwendung w&auml;re zum Beispiel der einfache Zugriff auf h&auml;ufig verwendete Tags. Das Men&uuml; wird &uuml;ber &#039;customdropdown&#039; in die Werkzeugleiste eingef&uuml;gt.';
$lang['startenabledtext'] = 'WYSIWYG aktiviert';
$lang['startenabledhelp'] = 'Wenn Sie dieses Feld deaktivieren, wird TinyMCE mit deaktiviertem WYSIWYG-Editor gestartet. Mit dem Kontrollfeld &quot;WYSIWYG aktivieren/deaktivieren&quot; kann dieser dann bei Bedarf zugeschaltet werden.';
$lang['loadcmslinkertext'] = 'Den CMS-Linker laden';
$lang['loadcmslinkerhelp'] = 'Dies generiert den erforderlichen Javascript-Code, um den &#039;cmslinker&#039; in der Werkzeugleiste anzeigen zu k&ouml;nnen.';
$lang['cmslinkerstyletext'] = 'Stil des CMS-Linkers';
$lang['cmsselflinkstyle'] = 'Stil des cms_selflink Tags (unterst&uuml;tzt Pretty URLs)';
$lang['ahrefstyle'] = 'Stil des a-(Link)-Tags (unterst&uuml;tzt keine Pretty URLs)';
$lang['cmslinkeraddstext'] = 'CMS-Linker Erg&auml;nzungen erlauben';
$lang['cmslinkeraddshelp'] = 'Damit k&ouml;nnen Sie erlauben, dass dem <a href>-Tag oder {cms_selflink} weitere Parameter mitgegeben werden k&ouml;nnen, wenn diese durch den CMS-linker erzeugt werden.';
$lang['avoidlinkconversiontext'] = 'Linkumwandlung deaktivieren';
$lang['avoidlinkconversionhelp'] = 'Deaktiviert die in TinyMCE eingebaute Linkumwandlung. Damit k&ouml;nnen Smarty-Anweisungen in URLs verwendet werden.';
$lang['relativeurlstext'] = 'Relative URLs erzeugen';
$lang['forcecleanpastetext'] = 'Bereinigung des Quellcodes beim Einf&uuml;gen erzwingen';
$lang['forcecleanpastehelp'] = 'Dies sollte aktiviert werden, um unsinnige Formatierungen, wie sie zum Beispiel beim Einf&uuml;gen von Text aus Word usw. auftreten, zu entfernen.';
$lang['bodycss_text'] = 'CSS-Bodytag';
$lang['bodycss_help'] = 'Um den CSS-Style Ihrer Seite zu verwenden, lassen Sie das Feld leer oder setzen es auf &bdquo;default&ldquo;. Tipp: Um den Hintergrund des Editors wei&szlig; einzuf&auml;rben, m&uuml;ssen Sie dies eintragen: <code>background-color:white;</code>';
$lang['includeonlyscreencss_text'] = 'Nur die Bildschirm-CSS einbinden';
$lang['includeonlyscreencss_help'] = 'Wenn Sie diese Option ausw&auml;hlen, werden in den Styles von TinyMCE nur Stylesheets des Medientyps &bdquo;Screen&ldquo; angezeigt.';
$lang['usestaticconfigtext'] = 'Eine statische Konfigurationsdatei verwenden';
$lang['usestaticconfighelp'] = 'Diese Option kann helfen, TinyMCE auf Hosting-Accounts lauff&auml;hig zu bekommen, bei denen der Hoster diverse Sachen wie Statistiken und &auml;hnliches in die Ausgabe einbindet, wodurch jedoch eine dynamisch via Javascript erzeugte Konfigurationsdatei zerst&ouml;rt wird.';
$lang['usestaticconfigwarning'] = 'Warnung! Sie haben die Option f&uuml;r eine statische Konfigurationsdatei aktiviert, aber Ihr /tmp-Verzeichnis ist nicht beschreibbar. Dies hindert das Modul an der Speicherung der statischen Konfigurationsdatei, wodurch TinyMCE h&ouml;chstwahrscheinlich nicht funktionieren wird.';
$lang['ignoremodifyfilestext'] = 'Die Berechtigung &#039;Modify Files&#039; f&uuml;r den FilePicker ignorieren';
$lang['ignoremodifyfileshelp'] = 'Warnung! Damit erlauben Sie einige Optionen zur Dateiverwaltung, obwohl die Berechtigung &#039;Modify Files&#039; f&uuml;r die aktuelle Benutzergruppe nicht gesetzt wurde. Dies kann effizient mit der Option zur Beschr&auml;nkung der Verzeichnisberechtigungen eingesetzt werden.';
$lang['showtogglebutton_text'] = 'Kontrollfeld zum Aktiveren/Deaktivieren der WYSIWYG-Option anzeigen';
$lang['togglewysiwyg'] = 'WYSIWYG aktivieren/deaktivieren';
$lang['styles_tab'] = 'CSS-Stile';
$lang['styles_help'] = 'Ohne Vorgabe wird TinyMCE Ihre CSS-Datei verarbeiten und dem Benutzer die Stile in einer Liste anzeigen. 
Wenn Sie dem Benutzer nur ein paar Stile angezeigen m&ouml;chten, k&ouml;nnen Sie dies mit &bdquo;benutzerdefinierterName1=stil1; benutzerdefinierterName2=stil2&ldquo; im ersten Feld festlegen.
&bdquo;stil1&ldquo; entspricht der CSS-Klasse in Ihrem Stylesheet. Der Punkt f&uuml;r die Klasse darf nicht eingegeben werden. Die ausgegebene Formatierung wird dann in etwa so aussehen:
<code>&amp;lt;span class=&quot;stil1&quot;&amp;gt;text&amp;lt;/span&amp;gt;</code> ';
$lang['css_styles_text'] = 'Stile';
$lang['accessdenied'] = 'Zugriff verweigert. Bitte pr&uuml;fen Sie Ihre Berechtigungen.';
$lang['error'] = 'Fehler!';
$lang['submit'] = 'Speichern';
$lang['update'] = 'Aktualisieren';
$lang['savesettings'] = 'Einstellungen speichern';
$lang['settings'] = 'Einstellungen';
$lang['settingssaved'] = 'Die Einstellungen wurden gespeichert.';
$lang['saveadvanced'] = 'Die erweiterten Einstellungen speichern';
$lang['advancedsaved'] = 'Die erweiterten Einstellungen wurden gespeichert.';
$lang['toolbarsaved'] = 'Die Werkzeugleiste wurde gespeichert.';
$lang['stylessaved'] = 'Die Stile wurden gespeichert.';
$lang['testareatext'] = '<p>Testfeld zum Ausprobieren &ndash; es werden keine Inhalte besch&auml;digt.</p>';
$lang['reset'] = 'Auf die programmseitigen Vorgaben zur&uuml;cksetzen';
$lang['resetall'] = 'Alle Einstellungen auf die programmseitigen Vorgaben zur&uuml;cksetzen';
$lang['confirmreset'] = 'Wollen Sie wirklich diese Einstellungen auf die programmseitigen Vorgaben zur&uuml;cksetzen?';
$lang['confirmresetall'] = 'Wollen Sie wirklich ALLE Einstellungen auf die programmseitigen Vorgaben zur&uuml;cksetzen?';
$lang['settingsreset'] = 'Diese Einstellungen wurden auf die programmseitigen Vorgaben zur&uuml;ckgesetzt';
$lang['allsettingsreset'] = 'Alle Einstellungen wurden auf die programmseitigen Vorgaben zur&uuml;ckgesetzt';
$lang['upgraded'] = 'wurde auf Version %s aktualisiert';
$lang['customdropdown'] = 'Benutzerdefiniertes Listenfeld-Men&uuml;';
$lang['cmsmslinker'] = 'Einen Link auf eine CMSms-Seite einf&uuml;gen';
$lang['backend_toolbars'] = 'Einstellungen f&uuml;r die Werkzeugleiste in der Administration';
$lang['frontend_toolbars'] = 'Einstellungen f&uuml;r die Werkzeugleiste auf der Webseite';
$lang['plugins_tab'] = 'Erweiterungen';
$lang['plugins_help'] = 'W&auml;hlen Sie die TinyMCE-Erweiterungen aus, die aktiviert werden sollen. Weitere Informationen finden Sie in der <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">Dokumentation</a>.';
$lang['plugins_text'] = 'Plugins ';
$lang['saveplugins'] = 'Plugin-Auswahl speichern';
$lang['pluginssaved'] = 'Plugin-Auswahl gespeichert';
$lang['plugins_module'] = 'Modul-Plugins';
$lang['plugins_common'] = 'Andere Plugins';
$lang['module'] = 'Modul';
$lang['description'] = 'Beschreibung';
$lang['plugin'] = 'Plugin ';
$lang['youareintext'] = 'Sie sind in ';
$lang['loadstylesheettext'] = 'Das Stylesheet f&uuml;r den Inhalt laden (empfohlen)';
$lang['extrastylestext'] = 'Das Stylesheet erg&auml;nzen mit';
$lang['extrastyleshelp'] = 'Hier eingegebene CSS wird dem Stylesheet hinzugef&uuml;gt, nachdem TinyMCE die CMSms-Stile gelesen hat.';
$lang['uploadnewfile'] = 'Neue Datei';
$lang['uploadfile'] = 'Hochladen';
$lang['createnewdir'] = 'Neues Verzeichnis';
$lang['createdir'] = 'Erstellen';
$lang['nodirname'] = 'Es wurde kein Verzeichnisname angegeben';
$lang['direxists'] = 'Dieser Verzeichnisname existiert bereits';
$lang['newdircreated'] = 'Das neue Verzeichnis wurde erstellt';
$lang['newdirfailed'] = 'Bei der Erstellung des Verzeichnisses ist ein Fehler aufgetreten';
$lang['nofile'] = 'Es wurde keine Datei hochgeladen';
$lang['filetoobig'] = 'Die hochgeladene Datei ist zu gro&szlig;';
$lang['containsillegalchars'] = 'Der Dateiname enth&auml;lt ein oder mehrere nicht erlaubte Zeichen (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['uploadfailed'] = 'Beim Verschieben der hochgeladenen Datei an die vorgegebene Stelle ist ein Fehler aufgetreten.';
$lang['fileuploaded'] = 'Die Datei wurde hochgeladen';
$lang['notanimage'] = 'Die hochgeladene Datei ist kein Bild';
$lang['filepickertitle'] = 'CMS-Made-Simple-Dateiauswahl';
$lang['success'] = 'Erledigt';
$lang['fileoperations'] = 'Dateioperationen';
$lang['thousanddelimiter'] = ', ';
$lang['size'] = 'Gr&ouml;&szlig;e';
$lang['dimensions'] = 'BxH';
$lang['advanced_tab'] = 'Weitere Optionen';
$lang['help'] = '       <h3>Was macht dieses Modul?</h3>
	<p>Es stellt den TinyMCE als WYSIWYG-Editor zur Verf&uuml;gung.</p>
	<h3>Wie wird es benutzt?</h3>
	<p>Nach der Installation k&ouml;nnen Sie in der Administration im Men&uuml; &bdquo;Meine Einstellungen -> Benutzerspezifische Einstellungen&ldquo; TinyMCE als WYSIWYG-Editor ausw&auml;hlen.</p>
  <h3>Sprachpr&uuml;fung</h3>
  <p>Seit Version 2.6.0 enth&auml;lt TinyMCE eine online Sprachpr&uuml;fung. Bitte beachten Sie, dass in Ihrer Server-Konfiguration SSL aktiviert sein muss, damit dies funktioniert. Bei einigen Installationen wird diese Option php_openssl genannt, dies kann aber auch davon abweichen.</p>
	<h3>Fehlersuche</h3>
	<p>Einige Anwender haben Probleme mit der Anzeige des TinyMCE nach der Installation oder Aktualisierung. Im folgenden finden Sie eine Checkliste, 
	die Sie abarbeiten sollten, bevor Sie mich um Unterst&uuml;tzung bitten.</p>
	<ol>
	<li>Bitte, bitte versuchen Sie, das TinyMCE-Verzeichnis nochmals in den /modules-Ordner hochzuladen. Sie w&auml;ren &uuml;berrascht, wenn Sie w&uuml;ssten, wie oft dies bereits anderen Anwendern geholfen hat.</li>
	<li>Versuchen Sie, die Option f&uuml;r eine statische Konfigurationsdatei zu verwenden. Bitte beachten Sie, dass daf&uuml;r ihr /tmp-Verzeichnis durch den Webserver beschreibbar sein muss.</li>
	<li>Falls Sie das Modul aktualisiert haben, versuchen Sie, s&auml;mtliche Einstellungen auf die programmseitigen Vorgaben zur&uuml;ckzusetzen. Ich wei&szlig;, dass das nicht gerade sch&ouml;n ist, wenn Sie TinyMCE bereits individuell angepasst hatten, aber mit der Umstellung des Moduls von 2.3.x auf 2.4.x sind eine Menge &Auml;nderungen erfolgt.</li>
	<li>Versuchen Sie, in der Registerkarte &bdquo;Weitere Optionen&ldquo; die Option zur Verwendung einer statischen Konfigurationsdatei zu verwenden. Auf manchen (CGI-basierten) Systemen funktioniert dies besser. Bitte beachten Sie, dass daf&uuml;r das Verzeichnis /tmp/ durch den Webserver beschreibbar sein muss.</li>
	</ol>
  <h3>Plugin-Programmierung</h3>
  <p>Ab Version 2.7.0 des TinyMCE-Moduls kann anderen Modulen erlaubt werden, Erweiterungen f&uuml;r diese zu registrieren. Dies k&ouml;nnte zum Beispiel ein benutzerdefiniertes Ikon sein, mit dem Inhalte von anderen Module eingef&uuml;gt werden k&ouml;nnen, wie zum Beispiel eine Bildergalerie. Wenn Sie ein Modul-Programmierer sind und mehr &uuml;ber die technischen Hintergr&uuml;nde erfahren m&ouml;chten, finden Sie im Verzeichnis TinyMCE/docs weitere Informationen.
';
$lang['utma'] = '156861353.178890951.1298889837.1299177721.1299280219.6';
$lang['utmz'] = '156861353.1298889837.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>